# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/truco',
                'doc_host': 'https://lgvaz.github.io',
                'git_url': 'https://github.com/lgvaz/truco',
                'lib_path': 'truco'},
  'syms': { 'truco.core': { 'truco.core.cards2ranks': ( 'https://lgvaz.github.io/core.html#cards2ranks',
                                                        'https://github.com/lgvaz/truco/blob/master/truco/core.py#L25'),
                            'truco.core.get_trump_round_rank': ( 'https://lgvaz.github.io/core.html#get_trump_round_rank',
                                                                 'https://github.com/lgvaz/truco/blob/master/truco/core.py#L16')},
            'truco.core_old': { 'truco.core_old.foo': ( 'https://lgvaz.github.io/core_old.html#foo',
                                                        'https://github.com/lgvaz/truco/blob/master/truco/core_old.py#L7')},
            'truco.monte': { 'truco.monte.foo': ( 'https://lgvaz.github.io/core_old-copy1.html#foo',
                                                  'https://github.com/lgvaz/truco/blob/master/truco/monte.py#L14')}}}